# Kasumi
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff) [![image](https://img.shields.io/pypi/v/kasumi-web.svg)](https://pypi.python.org/pypi/kasumi-web) [![image](https://img.shields.io/pypi/pyversions/kasumi-web.svg)](https://pypi.python.org/pypi/kasumi-web)

> [!WARNING]
> Kasumi is in a very early development stage. Do not use it in a production environment.

Kasumi (“霞” in Japanese Kanji) is an ASGI web server implemented almost from scratch using Starlette as the ASGI toolkit.
## Installing
~~Kasumi is published on PyPI and can be installed with the following command.~~
> [!IMPORTANT]
> Kasumi is not currently registered with PyPI. Please check the [following issue](https://github.com/AmaseCocoa/Kasumi/issues/1) for more information.
```
pip install kasumi
```
> [!NOTE]
> Installation via PyPI is now possible by acquiring the `Kasumi-web` namespace.
> ```
> pip install kasumi-web
> ```

#### If install the latest development version: 
```
pip install https://github.com/AmaseCocoa/Kasumi/archive/develop.zip
```

## Examples
Examples are available at [Example Directory](https://github.com/AmaseCocoa/Kasumi/blob/develop/example).
## License
Kasumi is available under the MIT License.